Changes for May 2022, syncing up to v413

This commit is contained in:
Andy CrossGate Yan
2022-05-12 00:37:03 +00:00
parent 3f1880e5fa
commit 969f476c22
104 changed files with 918 additions and 999 deletions

View File

@@ -1,7 +1,7 @@
From 5d89c5d4528ff7a271090f1fcbfa836cda85d2bf Mon Sep 17 00:00:00 2001
From 3092553e69dcf3976fe329939cc56fb2e9e2a4cc Mon Sep 17 00:00:00 2001
From: Andy CrossGate Yan <GeForce8800Ultra@gmail.com>
Date: Thu, 13 Jan 2022 14:22:24 +0000
Subject: [PATCH 01/21] Add SPenPointerOverlay
Subject: [PATCH 01/19] Add SPenPointerOverlay
Toggle this overlay with property "persist.ui.spen.pointer"

View File

@@ -1,7 +1,7 @@
From c88dfffaa49ca9781cc1bec87ff319b956fbe320 Mon Sep 17 00:00:00 2001
From 6b598113408b5e7f8fc425efd86779e96c0d7e69 Mon Sep 17 00:00:00 2001
From: Andy CrossGate Yan <GeForce8800Ultra@gmail.com>
Date: Thu, 5 Apr 2018 10:01:19 +0800
Subject: [PATCH 03/21] Disable vendor mismatch warning
Subject: [PATCH 02/19] Disable vendor mismatch warning
Change-Id: Ieb8fe91e2f02462f074312ed0f4885d183e9780b
---

View File

@@ -1,334 +0,0 @@
From e7f6397daa3b9761756e5fef41a32b7401541192 Mon Sep 17 00:00:00 2001
From: Andy CrossGate Yan <GeForce8800Ultra@gmail.com>
Date: Mon, 14 Mar 2022 08:20:43 +0000
Subject: [PATCH 02/21] UI: Monet: Default to Lineage Teal
Embrace Monet, but also maintain some LOS identity
Applies the signature teal of LineageOS (#167C80) as fallback (e.g. with live wallpapers)
Change-Id: Ida88fa1d891223ad11e058d24b3c96bebbc9cd62
---
core/res/res/values/colors.xml | 120 +++++++++---------
.../com/android/systemui/monet/ColorScheme.kt | 14 +-
2 files changed, 67 insertions(+), 67 deletions(-)
diff --git a/core/res/res/values/colors.xml b/core/res/res/values/colors.xml
index 59d6005ba193..36cf03f5268e 100644
--- a/core/res/res/values/colors.xml
+++ b/core/res/res/values/colors.xml
@@ -245,200 +245,200 @@
<!-- Lightest shade of the accent color used by the system. White.
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent1_0">#ffffff</color>
+ <color name="system_accent1_0">#FFFFFF</color>
<!-- Shade of the accent system color at 99% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent1_10">#F9FCFF</color>
+ <color name="system_accent1_10">#EFFFFF</color>
<!-- Shade of the accent system color at 95% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent1_50">#E0F3FF</color>
+ <color name="system_accent1_50">#B4FDFF</color>
<!-- Shade of the accent system color at 90% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent1_100">#C1E8FF</color>
+ <color name="system_accent1_100">#6EF6FC</color>
<!-- Shade of the accent system color at 80% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent1_200">#76D1FF</color>
+ <color name="system_accent1_200">#4CD9E0</color>
<!-- Shade of the accent system color at 70% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent1_300">#4BB6E8</color>
+ <color name="system_accent1_300">#1EBDC4</color>
<!-- Shade of the accent system color at 60% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent1_400">#219BCC</color>
+ <color name="system_accent1_400">#00A1A7</color>
<!-- Shade of the accent system color at 49.6% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent1_500">#007FAC</color>
+ <color name="system_accent1_500">#008388</color>
<!-- Shade of the accent system color at 40% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent1_600">#00668B</color>
+ <color name="system_accent1_600">#00696E</color>
<!-- Shade of the accent system color at 30% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent1_700">#004C69</color>
+ <color name="system_accent1_700">#004F53</color>
<!-- Shade of the accent system color at 20% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent1_800">#003549</color>
+ <color name="system_accent1_800">#00373A</color>
<!-- Shade of the accent system color at 10% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent1_900">#001E2C</color>
+ <color name="system_accent1_900">#002022</color>
<!-- Darkest shade of the accent color used by the system. Black.
This value can be overlaid at runtime by OverlayManager RROs. -->
<color name="system_accent1_1000">#000000</color>
<!-- Lightest shade of the secondary accent color used by the system. White.
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent2_0">#ffffff</color>
+ <color name="system_accent2_0">#FFFFFF</color>
<!-- Shade of the secondary accent system color at 99% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent2_10">#F9FCFF</color>
+ <color name="system_accent2_10">#EFFFFF</color>
<!-- Shade of the secondary accent system color at 95% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent2_50">#E0F3FF</color>
+ <color name="system_accent2_50">#DAF6F7</color>
<!-- Shade of the secondary accent system color at 90% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent2_100">#D1E5F4</color>
+ <color name="system_accent2_100">#CCE8E8</color>
<!-- Shade of the secondary accent system color at 80% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent2_200">#B5CAD7</color>
+ <color name="system_accent2_200">#B0CCCC</color>
<!-- Shade of the secondary accent system color at 70% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent2_300">#9AAEBB</color>
+ <color name="system_accent2_300">#96B0B1</color>
<!-- Shade of the secondary accent system color at 60% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent2_400">#8094A0</color>
+ <color name="system_accent2_400">#7B9697</color>
<!-- Shade of the secondary accent system color at 49.6% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent2_500">#657985</color>
+ <color name="system_accent2_500">#617B7C</color>
<!-- Shade of the secondary accent system color at 40% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent2_600">#4E616C</color>
+ <color name="system_accent2_600">#496364</color>
<!-- Shade of the secondary accent system color at 30% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent2_700">#374955</color>
+ <color name="system_accent2_700">#324B4D</color>
<!-- Shade of the secondary accent system color at 20% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent2_800">#20333D</color>
+ <color name="system_accent2_800">#1B3436</color>
<!-- Shade of the secondary accent system color at 10% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent2_900">#091E28</color>
+ <color name="system_accent2_900">#051F21</color>
<!-- Darkest shade of the secondary accent color used by the system. Black.
This value can be overlaid at runtime by OverlayManager RROs. -->
<color name="system_accent2_1000">#000000</color>
<!-- Lightest shade of the tertiary accent color used by the system. White.
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent3_0">#ffffff</color>
+ <color name="system_accent3_0">#FFFFFF</color>
<!-- Shade of the tertiary accent system color at 99% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent3_10">#FFFBFF</color>
+ <color name="system_accent3_10">#FDFCFF</color>
<!-- Shade of the tertiary accent system color at 95% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent3_50">#F5EEFF</color>
+ <color name="system_accent3_50">#EBF1FF</color>
<!-- Shade of the tertiary accent system color at 90% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent3_100">#E6DEFF</color>
+ <color name="system_accent3_100">#D4E3FF</color>
<!-- Shade of the tertiary accent system color at 80% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent3_200">#CAC1EA</color>
+ <color name="system_accent3_200">#ACC8F7</color>
<!-- Shade of the tertiary accent system color at 70% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent3_300">#AEA6CE</color>
+ <color name="system_accent3_300">#91ACDB</color>
<!-- Shade of the tertiary accent system color at 60% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent3_400">#938CB1</color>
+ <color name="system_accent3_400">#7692BE</color>
<!-- Shade of the tertiary accent system color at 49% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent3_500">#787296</color>
+ <color name="system_accent3_500">#5C77A2</color>
<!-- Shade of the tertiary accent system color at 40% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent3_600">#605A7C</color>
+ <color name="system_accent3_600">#445F8A</color>
<!-- Shade of the tertiary accent system color at 30% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent3_700">#484264</color>
+ <color name="system_accent3_700">#2B4770</color>
<!-- Shade of the tertiary accent system color at 20% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent3_800">#322C4C</color>
+ <color name="system_accent3_800">#113158</color>
<!-- Shade of the tertiary accent system color at 10% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_accent3_900">#1D1736</color>
+ <color name="system_accent3_900">#001B3D</color>
<!-- Darkest shade of the tertiary accent color used by the system. Black.
This value can be overlaid at runtime by OverlayManager RROs. -->
<color name="system_accent3_1000">#000000</color>
<!-- Lightest shade of the neutral color used by the system. White.
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_neutral1_0">#ffffff</color>
+ <color name="system_neutral1_0">#FFFFFF</color>
<!-- Shade of the neutral system color at 99% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_neutral1_10">#FCFCFF</color>
+ <color name="system_neutral1_10">#FAFDFC</color>
<!-- Shade of the neutral system color at 95% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_neutral1_50">#F0F0F3</color>
+ <color name="system_neutral1_50">#EFF1F1</color>
<!-- Shade of the neutral system color at 90% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_neutral1_100">#E1E3E5</color>
+ <color name="system_neutral1_100">#E0E3E2</color>
<!-- Shade of the neutral system color at 80% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_neutral1_200">#C5C7C9</color>
+ <color name="system_neutral1_200">#C4C7C6</color>
<!-- Shade of the neutral system color at 70% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_neutral1_300">#AAABAE</color>
+ <color name="system_neutral1_300">#A9ACAB</color>
<!-- Shade of the neutral system color at 60% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_neutral1_400">#8F9193</color>
+ <color name="system_neutral1_400">#8E9191</color>
<!-- Shade of the neutral system color at 49% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_neutral1_500">#747679</color>
+ <color name="system_neutral1_500">#737776</color>
<!-- Shade of the neutral system color at 40% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_neutral1_600">#5C5F61</color>
+ <color name="system_neutral1_600">#5B5F5F</color>
<!-- Shade of the neutral system color at 30% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_neutral1_700">#454749</color>
+ <color name="system_neutral1_700">#444747</color>
<!-- Shade of the neutral system color at 20% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_neutral1_800">#2E3133</color>
+ <color name="system_neutral1_800">#2E3131</color>
<!-- Shade of the neutral system color at 10% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_neutral1_900">#191C1E</color>
+ <color name="system_neutral1_900">#191C1C</color>
<!-- Darkest shade of the neutral color used by the system. Black.
This value can be overlaid at runtime by OverlayManager RROs. -->
<color name="system_neutral1_1000">#000000</color>
<!-- Lightest shade of the secondary neutral color used by the system. White.
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_neutral2_0">#ffffff</color>
+ <color name="system_neutral2_0">#FFFFFF</color>
<!-- Shade of the secondary neutral system color at 99% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_neutral2_10">#F9FCFF</color>
+ <color name="system_neutral2_10">#F4FEFE</color>
<!-- Shade of the secondary neutral system color at 95% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_neutral2_50">#EBF1F8</color>
+ <color name="system_neutral2_50">#E8F3F2</color>
<!-- Shade of the secondary neutral system color at 90% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_neutral2_100">#DCE3E9</color>
+ <color name="system_neutral2_100">#DAE5E4</color>
<!-- Shade of the secondary neutral system color at 80% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_neutral2_200">#C0C7CD</color>
+ <color name="system_neutral2_200">#BEC8C9</color>
<!-- Shade of the secondary neutral system color at 70% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_neutral2_300">#A5ACB2</color>
+ <color name="system_neutral2_300">#A3ADAE</color>
<!-- Shade of the secondary neutral system color at 60% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_neutral2_400">#8A9297</color>
+ <color name="system_neutral2_400">#889393</color>
<!-- Shade of the secondary neutral system color at 49% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_neutral2_500">#70777C</color>
+ <color name="system_neutral2_500">#6E7878</color>
<!-- Shade of the secondary neutral system color at 40% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_neutral2_600">#585F65</color>
+ <color name="system_neutral2_600">#566061</color>
<!-- Shade of the secondary neutral system color at 30% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_neutral2_700">#40484D</color>
+ <color name="system_neutral2_700">#3F4949</color>
<!-- Shade of the secondary neutral system color at 20% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_neutral2_800">#2A3136</color>
+ <color name="system_neutral2_800">#293232</color>
<!-- Shade of the secondary neutral system color at 10% perceptual luminance (L* in L*a*b* color space).
This value can be overlaid at runtime by OverlayManager RROs. -->
- <color name="system_neutral2_900">#161C20</color>
+ <color name="system_neutral2_900">#141D1E</color>
<!-- Darkest shade of the secondary neutral color used by the system. Black.
This value can be overlaid at runtime by OverlayManager RROs. -->
<color name="system_neutral2_1000">#000000</color>
--
2.25.1

View File

@@ -1,7 +1,7 @@
From 25f408530b37ae70f3699a8ae88115c457b6275f Mon Sep 17 00:00:00 2001
From ba083752bf0310ee14884e4a2fe3e3e5846c62b5 Mon Sep 17 00:00:00 2001
From: Andy CrossGate Yan <GeForce8800Ultra@gmail.com>
Date: Sat, 16 Oct 2021 02:23:48 +0000
Subject: [PATCH 04/21] UI: Adjust default navbar layouts
Subject: [PATCH 03/19] UI: Adjust default navbar layouts
- Slightly tighten nodpi layout
- Remove sw372dp layout - looks terrible, probably meant for legacy phablets, but most modern phones qualify

View File

@@ -1,7 +1,7 @@
From ea79f27d909514d39bdf056bafa57ba38d69e0f8 Mon Sep 17 00:00:00 2001
From d461abc9968ac7937e5530efd15d46671565c316 Mon Sep 17 00:00:00 2001
From: Andy CrossGate Yan <GeForce8800Ultra@gmail.com>
Date: Fri, 9 Mar 2018 15:41:26 +0800
Subject: [PATCH 05/21] UI: Disable left (seascape) navigation bar optionally
Subject: [PATCH 04/19] UI: Disable left (seascape) navigation bar optionally
Toggle this behaviour with property "persist.ui.seascape.disable"

View File

@@ -1,7 +1,7 @@
From 5f43af1daea3fc2cc9d9b3368830bed714ab2633 Mon Sep 17 00:00:00 2001
From a996ded413ad03db5074c8cf32858e478d196fc7 Mon Sep 17 00:00:00 2001
From: Andy CrossGate Yan <GeForce8800Ultra@gmail.com>
Date: Sun, 10 Jan 2021 11:44:29 +0000
Subject: [PATCH 06/21] UI: Disable wallpaper zoom
Subject: [PATCH 05/19] UI: Disable wallpaper zoom
It does little more than inducing motion sickness

View File

@@ -1,7 +1,7 @@
From 1767820053fc9f52bd8409fb6aa1c56f2f790710 Mon Sep 17 00:00:00 2001
From 972bc4938064c391290503d7fbeb200e339fe326 Mon Sep 17 00:00:00 2001
From: Andy CrossGate Yan <GeForce8800Ultra@gmail.com>
Date: Wed, 3 Jun 2020 01:31:34 +0000
Subject: [PATCH 07/21] UI: Increase default status bar height
Subject: [PATCH 06/19] UI: Increase default status bar height
Change-Id: Ibbcf63159e19bb2bb2b1094ea07ab85917630b07
---

View File

@@ -1,7 +1,7 @@
From f947d96463246f92ed606028dd1e4b4941769b7b Mon Sep 17 00:00:00 2001
From e31ba474b5b86eefe07fdd630c761fc035a0e05f Mon Sep 17 00:00:00 2001
From: Andy CrossGate Yan <GeForce8800Ultra@gmail.com>
Date: Sat, 19 Mar 2022 09:22:24 +0000
Subject: [PATCH 08/21] UI: Restore split-screen divider to pre-Sv2 looks
Subject: [PATCH 07/19] UI: Restore split-screen divider to pre-Sv2 looks
- Kill rounded corners - where two rectangles collide should be perfectly straight
- Make it black again - taskbar should mind its own business

View File

@@ -1,7 +1,7 @@
From 359469b002fb3eb561ebebeacf879d644d920ba0 Mon Sep 17 00:00:00 2001
From bb47f4b8d64a57c3eb5dae7a13c3abdac8533736 Mon Sep 17 00:00:00 2001
From: Andy CrossGate Yan <GeForce8800Ultra@gmail.com>
Date: Tue, 6 Oct 2020 01:41:16 +0000
Subject: [PATCH 09/21] UI: Revive navbar layout tuning via sysui_nav_bar
Subject: [PATCH 08/19] UI: Revive navbar layout tuning via sysui_nav_bar
tunable
Google keeps fixing what ain't broken.

View File

@@ -1,7 +1,7 @@
From 820961bea92232ff501ebaa8e9a0208b837d9fbc Mon Sep 17 00:00:00 2001
From 30cb3ac5413b13486cf8a4035aaf58f302f6c922 Mon Sep 17 00:00:00 2001
From: Andy CrossGate Yan <GeForce8800Ultra@gmail.com>
Date: Sun, 26 Apr 2020 08:56:13 +0000
Subject: [PATCH 10/21] UI: Use SNAP_FIXED_RATIO for multi-window globally
Subject: [PATCH 09/19] UI: Use SNAP_FIXED_RATIO for multi-window globally
Enables multiple snap targets under landscape for phone UI

View File

@@ -1,7 +1,7 @@
From 398c29806a00747c917562f369f1e145a8ced079 Mon Sep 17 00:00:00 2001
From 7a1136397113e10afc36276f70f62083c20abe95 Mon Sep 17 00:00:00 2001
From: Danny Lin <danny@kdrag0n.dev>
Date: Tue, 3 Nov 2020 22:43:12 -0800
Subject: [PATCH 11/21] core: Remove old app target SDK dialog
Subject: [PATCH 10/19] core: Remove old app target SDK dialog
If an app is old, users should already know that, and there's usually no
point in warning them about it because they would already be using a

View File

@@ -1,7 +1,7 @@
From 3185f1dfa835f44776fdfdb4533d352006dd8349 Mon Sep 17 00:00:00 2001
From 00f4d1dfbf1e280000872545d873fef7fec30ba0 Mon Sep 17 00:00:00 2001
From: Danny Lin <danny@kdrag0n.dev>
Date: Tue, 8 Mar 2022 20:37:33 -0800
Subject: [PATCH 12/21] SystemUI: Always refresh power menu on UI mode change
Subject: [PATCH 11/19] SystemUI: Always refresh power menu on UI mode change
This is necessary for reliably theming the global actions dialog with
dynamic colors and adapting it to light/dark themes.

View File

@@ -1,7 +1,7 @@
From 812d2f8e61a60008d2e2a40d20279bb9a8e822a1 Mon Sep 17 00:00:00 2001
From b708cbead42948667b098a818432c073169c6ffa Mon Sep 17 00:00:00 2001
From: Danny Lin <danny@kdrag0n.dev>
Date: Sat, 9 Oct 2021 14:39:38 -0700
Subject: [PATCH 13/21] SystemUI: Use Monet colors for power menu
Subject: [PATCH 12/19] SystemUI: Use Monet colors for power menu
It's odd that the power menu doesn't use Monet colors, unlike most of
System UI. This makes it feel more integrated with the rest of the

View File

@@ -1,7 +1,7 @@
From 61d33e3c7c715f8545d87414dcc7d552ea74817f Mon Sep 17 00:00:00 2001
From 485e73406b919813149356a66bb3b92c5a4fd216 Mon Sep 17 00:00:00 2001
From: Danny Lin <danny@kdrag0n.dev>
Date: Wed, 6 Oct 2021 18:40:30 -0700
Subject: [PATCH 14/21] Revert "Make QS always use dark theme colors"
Subject: [PATCH 13/19] Revert "Make QS always use dark theme colors"
This reverts commit d62f7249f9e3222da95ecf6816601c408aac6be5.

View File

@@ -1,7 +1,7 @@
From 29f62822e50aeb4e4f55ca19f6c4e5c5446500b1 Mon Sep 17 00:00:00 2001
From 3e3f73958f43aa63986cac35a119467ca4cafbd8 Mon Sep 17 00:00:00 2001
From: Danny Lin <danny@kdrag0n.dev>
Date: Wed, 6 Oct 2021 18:41:11 -0700
Subject: [PATCH 15/21] Revert "Do not re-inflate QS and SB when
Subject: [PATCH 14/19] Revert "Do not re-inflate QS and SB when
CONFIG_UI_MODE"
This reverts commit 8a40ff855b86bc86e23367017002289920855a4e.

View File

@@ -1,7 +1,7 @@
From a8a7179f4ff9e0eaa89a0521249cc18662d5cf0e Mon Sep 17 00:00:00 2001
From 11dd90792ba2293e623a686cea1f4a61ed292993 Mon Sep 17 00:00:00 2001
From: Danny Lin <danny@kdrag0n.dev>
Date: Mon, 11 Oct 2021 19:24:58 -0700
Subject: [PATCH 16/21] SystemUI: Follow light/dark theme in quick settings
Subject: [PATCH 15/19] SystemUI: Follow light/dark theme in quick settings
Android 12's dual-tone style where the quick settings panel is always
dark makes the light theme look like a second-class citizen. Pure black

View File

@@ -1,7 +1,7 @@
From 78256a2d065b0f0ee85221f92911e56389963d97 Mon Sep 17 00:00:00 2001
From 51ddcd1625e36db7a7817c8fdcf78008e3dcc472 Mon Sep 17 00:00:00 2001
From: Danny Lin <danny@kdrag0n.dev>
Date: Mon, 11 Oct 2021 19:25:02 -0700
Subject: [PATCH 17/21] SystemUI: Initialize QS tiles in inactive state
Subject: [PATCH 16/19] SystemUI: Initialize QS tiles in inactive state
Now that the QS fragment is recreated when changing the UI mode (so that
it follows light/dark themes), all tiles flash with active color briefly

View File

@@ -1,7 +1,7 @@
From be98345ce808cf14de1a8510fcdb32bb0a0bbc64 Mon Sep 17 00:00:00 2001
From 8015abe8a29cf35760b18691a8e732f0d1b84b65 Mon Sep 17 00:00:00 2001
From: Danny Lin <danny@kdrag0n.dev>
Date: Mon, 11 Oct 2021 19:25:08 -0700
Subject: [PATCH 18/21] SystemUI: Add dual-tone light and dark themes for QS
Subject: [PATCH 17/19] SystemUI: Add dual-tone light and dark themes for QS
Google's dual-tone QS design where the notification panel has a
semantically higher elevation adds depth to the notification+QS shade,

View File

@@ -1,7 +1,7 @@
From 6eebbd51cb280cb8322ea841ad91458d85d41183 Mon Sep 17 00:00:00 2001
From 757fc3ae84413ca0b158c1a4f5fa6b18d517beab Mon Sep 17 00:00:00 2001
From: Danny Lin <danny@kdrag0n.dev>
Date: Tue, 5 Oct 2021 21:01:50 -0700
Subject: [PATCH 19/21] Paint: Enable subpixel text positioning by default
Subject: [PATCH 18/19] Paint: Enable subpixel text positioning by default
On desktop Linux, subpixel text positioning is necessary to avoid
kerning issues, and Android is no different. Even though most phone

View File

@@ -1,7 +1,7 @@
From 321d9207a07cc8c129355e58c0dc0ef28e226c2d Mon Sep 17 00:00:00 2001
From 80a2541826f9faa2f58c135dcbafb81f1399dcfb Mon Sep 17 00:00:00 2001
From: SagarMakhar <sagarmakhar@gmail.com>
Date: Sat, 6 Nov 2021 13:16:24 +0000
Subject: [PATCH 21/21] Fix QS clock being white on light theme
Subject: [PATCH 19/19] Fix QS clock being white on light theme
Steps to reproduce without this commit:
- Turn off dark theme

View File

@@ -1,41 +0,0 @@
From 1c8f6f63245625aa095121a611ab67c39f061f77 Mon Sep 17 00:00:00 2001
From: Danny Lin <danny@kdrag0n.dev>
Date: Fri, 18 Mar 2022 23:19:54 -0700
Subject: [PATCH 20/21] monet: Fix overly low chroma for tones below 90
Chroma is capped to 40 for light colors of L* 90 and above for valid
reasons. However, assigning the capped value to "chroma" fails to
account for the fact that chroma is an argument passed to the method,
so the capping effect persists across iterations. This unintentionally
affects and limits the chroma of *all* shades because the first
iteration of the loop is L*=90.
As a result, almost all colors are less chromatic than the intended
chroma >= 48. Fix the issue by assigning capped chroma to a temporary
per-iteration variable.
Change-Id: I18102d0072c89535e27f23fdb98af7c83864ff7e
---
.../monet/src/com/android/systemui/monet/Shades.java | 6 ++----
1 file changed, 2 insertions(+), 4 deletions(-)
diff --git a/packages/SystemUI/monet/src/com/android/systemui/monet/Shades.java b/packages/SystemUI/monet/src/com/android/systemui/monet/Shades.java
index aab3538e3c4c..c5b9458614e1 100644
--- a/packages/SystemUI/monet/src/com/android/systemui/monet/Shades.java
+++ b/packages/SystemUI/monet/src/com/android/systemui/monet/Shades.java
@@ -59,10 +59,8 @@ public class Shades {
shades[1] = ColorUtils.CAMToColor(hue, Math.min(40f, chroma), 95);
for (int i = 2; i < 12; i++) {
float lStar = (i == 6) ? MIDDLE_LSTAR : 100 - 10 * (i - 1);
- if (lStar >= 90) {
- chroma = Math.min(40f, chroma);
- }
- shades[i] = ColorUtils.CAMToColor(hue, chroma, lStar);
+ float shadeChroma = (lStar >= 90) ? Math.min(40f, chroma) : chroma;
+ shades[i] = ColorUtils.CAMToColor(hue, shadeChroma, lStar);
}
return shades;
}
diff --git a/packages/SystemUI/monet/src/com/android/systemui/monet/ColorScheme.kt b/packages/SystemUI/monet/src/com/android/systemui/monet/ColorScheme.kt
index 0b3eccfd3a91..eabc1c510ecb 100644
--- a/packages/SystemUI/monet/src/com/android/systemui/monet/ColorScheme.kt
+++ b/packages/SystemUI/monet/src/com/android/systemui/monet/ColorScheme.kt
@@ -35,7 +35,7 @@ const val ACCENT3_HUE_SHIFT = 60.0f
const val NEUTRAL1_CHROMA = 4.0f
const val NEUTRAL2_CHROMA = 8.0f
-const val GOOGLE_BLUE = 0xFF1b6ef3.toInt()
+const val LINEAGE_TEAL = 0xFF167C80.toInt()
const val MIN_CHROMA = 5
@@ -76,9 +76,9 @@ public class ColorScheme(@ColorInt seed: Int, val darkTheme: Boolean) {
init {
val proposedSeedCam = Cam.fromInt(seed)
val seedArgb = if (seed == Color.TRANSPARENT) {
- GOOGLE_BLUE
+ LINEAGE_TEAL
} else if (proposedSeedCam.chroma < 5) {
- GOOGLE_BLUE
+ LINEAGE_TEAL
} else {
seed
}
@@ -140,7 +140,7 @@ public class ColorScheme(@ColorInt seed: Int, val darkTheme: Boolean) {
}.toList()
if (distinctColors.isEmpty()) {
- return listOf(GOOGLE_BLUE)
+ return listOf(LINEAGE_TEAL)
}
return distinctColors
}
@@ -204,8 +204,8 @@ public class ColorScheme(@ColorInt seed: Int, val darkTheme: Boolean) {
}
if (seeds.isEmpty()) {
- // Use gBlue 500 if there are 0 colors
- seeds.add(GOOGLE_BLUE)
+ // Use Lineage Teal 500 if there are 0 colors
+ seeds.add(LINEAGE_TEAL)
}
return seeds
@@ -259,4 +259,4 @@ public class ColorScheme(@ColorInt seed: Int, val darkTheme: Boolean) {
return huePopulation
}
}
-}
\ No newline at end of file
+}
--
2.25.1